==> haskell-http-download-0.2.1.0-318-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-AoDsIFjegNeY1k652XrTH
key:                  http-download-0.2.1.0-AoDsIFjegNeY1k652XrTH
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  25edfc05c32ca5521b98f2954436b459
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-AoDsIFjegNeY1k652XrTH
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    bytestring-0.11.5.3 conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6
    crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    crypton-conduit-0.2.3-3EN5zse1H5T29qz3O5MqJq directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-conduit-2.3.9.1-4fv8UoY8zTlKlPGaK7tn4g
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    path-0.9.6-JZJSfxZgLNX9Y539GdP67P
    path-io-1.8.2-CWPMy5Meh3QEKkmaY17vKO
    retry-0.9.3.1-FYTMxXzp6ILABIm5Dm7RjL
    rio-0.1.24.0-FBO4PrA6UlqFqVtMb3OxSz
    rio-prettyprint-0.1.8.0-4VEed9eIFha1YPzhahlWIJ

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-download-0.2.1.0-320-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-9UY1M7xeVpk4u0nXMZAsYq
key:                  http-download-0.2.1.0-9UY1M7xeVpk4u0nXMZAsYq
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  98092a0c040e346038de81d0e8bb1200
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-9UY1M7xeVpk4u0nXMZAsYq
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-LrCtfbXf96jILPXKH7KAXZ
    bytestring-0.11.5.3 conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy
    conduit-extra-1.3.8-GHF5wYhQp30HUaLAtCbs0G
    crypton-1.0.4-37TsNQoV8Vb5042LlXS4MC
    crypton-conduit-0.2.3-C3XT4NKKUAXEBDPgweQsL directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    http-client-0.7.19-HYRPxJ1velFCbteX9ut4f6
    http-conduit-2.3.9.1-4XCjseDTPMR1cOfyxjAQAe
    http-types-0.12.4-2YF0olXF9itCctWavExzmH
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    path-0.9.6-BfPc0tTnWDFIco9YzxzKzp
    path-io-1.8.2-jT5LkidbSC8X8P7dmIqx8
    retry-0.9.3.1-HM6wU7gRvnkCjjxIf9Mqp3
    rio-0.1.24.0-KVtH5Pu4lMV2pIyCm3kd0p
    rio-prettyprint-0.1.8.0-HdRcgeWmvcfKcoZxpVmw1t

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
